@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 my $log;
 my $bcmd;
@@ -549,7 +549,7 @@ sub _create_log {
         level => defined $level ? $level : 0,
     );
 
-    $self->{log}->_6("in _create_log()");
+    $self->{log}->_7("in _create_log()");
 
     if ($self->{log}->level < 6){
         $self->{log}->display(0);
@@ -581,7 +581,9 @@ sub _exec {
         $self->{args}{plugin_arg}
     );
 
-    $log->_6("instructions to be executed:\n" . join ', ', @exec_cmd);
+    chomp @exec_cmd;
+
+    $log->_6("instructions to be executed:\n" . join "\n", @exec_cmd);
 
     my $brew = $bcmd->brew;
 
@@ -691,8 +693,10 @@ sub _dzil_shim {
     my $path_sep = $self->is_win ? ';' : ':';
 
     if (! grep {-x "$_/dzil"} split /$path_sep/, $ENV{PATH} ){
-        $log->fatal("this appears to be a Dist::Zilla module, but the dzil binary " .
-              "can't be found\n");
+        $log->fatal(
+            "this appears to be a Dist::Zilla module, but the dzil binary " .
+            "can't be found\n"
+        );
     }
 
     $self->{is_dzil} = 1;
@@ -858,7 +862,9 @@ sub _set_plugin {
 
     my $self = shift;
     my $log = $log->child('_set_plugin');
-    my $plugin = $self->{args}{plugin} ? $self->{args}{plugin} : $ENV{TBB_PLUGIN};
+    my $plugin = $self->{args}{plugin}
+        ? $self->{args}{plugin}
+        : $ENV{TBB_PLUGIN};
 
     $log->_5("plugin param set to: " . defined $plugin ? $plugin : 'default');
 
@@ -907,12 +913,13 @@ dispatching capabilities.
 This module is the backend for the C<brewbuild> script that is accompanied by
 this module.
 
-For end-user use, see L<brewbuild|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/brewbuild>.
-You can also read the network test dispatcher C<bbdispatch> documentation
-L<here|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/bbdispatch>, the
-remote test listener C<bbtester> docs
-L<here|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/bbtester>, or
-browse through the L<Test::BrewBuild::Tutorial> for network testing.
+For end-user use, see
+L<brewbuild|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/brewbuild>.
+You can also read the documentation for the network dispatcher
+L<bbdispatch|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/bbdispatch>,
+the remote test listener
+L<bbtester|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/bbtester>,
+or browse through the L<Test::BrewBuild::Tutorial> for network testing.
 
 This module provides you the ability to perform your unit tests across all of
 your L<Perlbrew|http://perlbrew.pl> (Unix) or L<Berrybrew|https://github.com/stevieb9/berrybrew>
