@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 my $log;
 
@@ -17,7 +17,8 @@ sub new {
 
     $self->{log} = $plog->child('BrewCommands');
     $log = $self->{log};
-    $log->_6("constructing new Test::BrewBuild::BrewCommands object");
+
+    $log->child('new')->_7("instantiating new object");
 
     $self->brew;
 
@@ -75,7 +76,8 @@ sub using {
     $log->child( 'using' )->_6( "checking for which ver we're using" );
 
     if ($self->is_win) {
-        my @installed = $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]\s+\*/ig;
+        my @installed
+            = $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]\s+\*/ig;
         return $installed[0];
     }
     else {
