@@ -14,11 +14,11 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 $| = 1;
 
-my ($log, $last_run_status, $results_returned, $lcd);
+my ($log, $last_run_status, $results_returned);
 $ENV{BB_RUN_STATUS} = 'PASS';
 
 sub new {
@@ -33,6 +33,8 @@ sub new {
         $self->{debug} = $args{debug};
     }
 
+    $log->child('new')->_5("instantiating new object");
+
     if (defined $args{auto}){
         $self->{auto} = $args{auto};
         $self->{auto} = 0 if $self->{auto} == 1;
@@ -42,9 +44,6 @@ sub new {
     $self->{forks} = defined $args{forks} ? $args{forks} : 4;
     $self->{rpi} = defined $args{rpi} ? $args{rpi} : undef;
 
-    my $log = $log->child('new');
-    $log->_5("instantiating new Test::BrewBuild::Dispatch object");
-
     $self->_config;
 
     return $self;
@@ -103,8 +102,6 @@ sub auto {
             $results_returned = 0;
         }
 
-        my $commit = $git->revision(remote => 1, repo => $params{repo});
-        $commit = substr $commit, 0, 8;
     
         if ($self->{rpi}){
             $log->_7("RPi specific testing enabled");
@@ -113,15 +110,22 @@ sub auto {
                 my @pins = split /,/, $ENV{BB_RPI_LCD};
                 if (@pins == 6){
                     if ($results_returned){
-                        my $time = strftime("%Y-%m-%d %H:%M:%S\n", localtime(time));
+                        my $commit = $git->revision(remote => 1, repo => $params{repo});
+                        $commit = substr $commit, 0, 8;
+
+                        my $time = strftime(
+                            "%Y-%m-%d %H:%M:%S", localtime(time)
+                        );
                         
-                        $lcd = _lcd(@pins) if ! defined $lcd;
+                        my $lcd = _lcd(@pins);
+
+                        $lcd->clear;
 
                         $lcd->position(0, 0);
                         $lcd->print($time);
 
                         $lcd->position(0, 1);
-                        $lcd->print("$ENV{BB_RUN_STATUS}");
+                        $lcd->print($ENV{BB_RUN_STATUS});
 
                         $lcd->position(8, 1);
                         $lcd->print($commit);
@@ -155,7 +159,7 @@ sub auto {
     }
 }
 sub _lcd {
-    # used only for doing RPi::WiringPi unit test runs in auto mode
+    # used only for dispatching to an RPi in auto mode
 
     my @pins = @_;
 
@@ -365,18 +369,27 @@ sub _fork {
                     $log->_5("repo set to $repo_link from Git");
                 }
                 else {
-                    $log->_7("\$repo_link could not be set, we're about to fail...");
+                    $log->_7(
+                        "\$repo_link could not be set, we're about to fail..."
+                    );
                 }
             }
             else {
                 $repo_link = $repo;
-                $log->_5("repo sent in, and set to: $repo_link");
+                $log->_5("repo was sent in, and set to: $repo_link");
             }
 
             if (! $repo_link){
-                $log->_0("no repository supplied and not in a repo dir... croaking");
-                croak "\nno repository found, and none sent in via param, can't continue...\n";
+                $log->_0(
+                    "no repository supplied and not in a repo dir... croaking"
+                );
+                croak
+                    "\nno repository found, and none sent in via param, " .
+                    "can't continue...";
             }
+
+            $log->_6("dispatching out to and waiting for tester: '$tester'...");
+
             $socket->send($repo_link);
 
             my $ok = eval {
@@ -384,6 +397,8 @@ sub _fork {
                 1;
             };
 
+            $log->_7("tester work has concluded");
+
             if (! $ok && ! defined $self->{auto}){
                 $log->_0("errors occurred... check your command line " .
                          "string for invalid args. You sent in: $cmd.\n" .
@@ -393,7 +408,9 @@ sub _fork {
             }
         }
         else {
-            $log->_5("deleted tester: $remotes->{$tester}... incomplete session");
+            $log->_5(
+                "deleted tester: $remotes->{$tester}... incomplete session"
+            );
             delete $remotes->{$tester};
         }
         $socket->close();
