@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Logging::Simple;
 use LWP::Simple qw(head);
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 my $log;
 
@@ -24,7 +24,7 @@ sub new {
         $log->level($args{debug});
     }
 
-    $log->_5("instantiating new Test::BrewBuild::Git object");
+    $log->child('new')->_5("instantiating new object");
 
     return $self;
 }
@@ -32,6 +32,8 @@ sub git {
     my $self = shift;
     my $cmd;
 
+    return $self->{git} if defined $self->{git};
+
     if ($^O =~ /MSWin/){
         for (split /;/, $ENV{PATH}){
             if (-x "$_/git.exe"){
@@ -46,6 +48,8 @@ sub git {
 
     $log->child('git')->_6("git command set to '$cmd'");
 
+    $self->{git} = $cmd;
+
     return $cmd;
 }
 sub link {
@@ -96,6 +100,9 @@ sub revision {
     my ($self, %args) = @_;
 
     my $remote = $args{remote};
+    my $repo = $args{repo};
+
+    my $log = $log->child('revision');
 
     my $git = $self->git;
 
@@ -104,14 +111,26 @@ sub revision {
     my $csum;
 
     if (! $remote) {
+        $log->_6("local: 'rev-parse HEAD' sent");
         $csum = `"$git" rev-parse HEAD`;
     }
     else {
         # void capture, as there's unneeded stuff going to STDERR
         # on the ls-remote call
 
+        if (! defined $repo){
+            $log->_0(
+                "Git::revision() requires a repo sent in while in remote " .
+                "mode. Croaking."
+            ); 
+            croak "Git::revision() requires a repo sent in while in " .
+                  "remote mode.";
+        }
+
+        $log->_6("remote: 'ls-remote' sent");
+
         capture_stderr {
-            my $sums = `"$git" ls-remote`;
+            my $sums = `"$git" ls-remote $repo`;
             if ($sums =~ /([A-F0-9]{40})\s+HEAD/i){
                 $csum = $1;
             }
@@ -119,11 +138,14 @@ sub revision {
     }
 
     chomp $csum;
+    $log->_5("commit checksum: $csum");
     return $csum;
 }
 sub status {
     my ($self) = @_;
 
+    $log->child('status')->_7("checking git status");
+
     my $git = $self->git;
 
     my $status = `$git status`;
@@ -219,13 +241,14 @@ All parameters are passed in as a hash.
     repo
 
 Optional, string. The Github url to the repo. If not sent in, we will attempt
-to get this information from the current working directory.
+to get this information from the current working directory. Mandatory if the
+C<remote> parameter is sent in.
 
     remote
 
 Optional, bool. If sent in, we'll fetch the current commit's SHA1 sum from
 Github itself, else we'll get the sum from the most recent local, unpushed
-commit.
+commit. The C<repo> parameter is mandatory if this one is sent in.
 
 =head2 status
 
