@@ -13,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 $| = 1;
 
@@ -30,6 +30,12 @@ sub new {
     $self->{csum} = $args{csum};
 
     $log = Logging::Simple->new(level => 0, name => 'Tester');
+    $log->_7("instantiating new object");
+
+    if (defined $args{debug}){
+        $log->level($args{debug}) if defined $args{debug};
+        $self->{debug} = $args{debug};
+    }
 
     my $log_file = \$self->{log};
 
@@ -37,15 +43,24 @@ sub new {
         $log_file = Test::BrewBuild->workdir ."/bbtester_parent.log";
     }
 
-    $log->file($log_file) if ! $self->{log_to_stdout};
-
-    if (defined $args{debug}){
-        $log->level($args{debug}) if defined $args{debug};
-        $self->{debug} = $args{debug};
+    if ($self->{log_to_stdout}){
+        $log->_7("logging to STDOUT");
     }
 
-    my $log = $log->child('new');
-    $log->_5("instantiating new Test::BrewBuild::Tester object");
+    my $tester_log = $log->child('new');
+    $tester_log->_5("instantiating new Test::BrewBuild::Tester object");
+
+    my $arg_string;
+
+    for (keys %args){
+        next if ! defined $args{$_};
+        $arg_string .= "$_: $args{$_}\n";
+    }
+
+    if ($arg_string){
+        $tester_log->_7("args:");
+        $tester_log->_7("\n$arg_string");
+    }
 
     $self->_config;
     $self->_pid_file;
@@ -219,6 +234,8 @@ sub listen {
              "$self->{port}"
     );
 
+    $log->_7("$self->{ip} now accepting incoming connections");
+
     while (1){
 
         my $work_dir = Test::BrewBuild->workdir;
@@ -231,12 +248,10 @@ sub listen {
             platform => $Config{archname},
         };
 
-        $log->_7("platform: $res->{platform}");
+        $log->_7("platform: $res->{platform} waiting for a connection...\n");
 
         my $dispatch = $sock->accept;
 
-        $log->_7("now accepting incoming connections");
-
         # ack
         my $ack;
         $dispatch->recv($ack, 1024);
@@ -283,41 +298,43 @@ sub listen {
 
         if ($repo){
             my $git = Test::BrewBuild::Git->new(debug => $self->{debug});
+            $log->_7("using Git: " . $git->git);
 
             $log->_7("before all checks, repo set to $repo");
 
-            if (-d $git->name($repo)){
-                chdir $git->name($repo) or croak $!;
+            my $repo_name = $git->name($repo);
+
+            if (-d $repo_name){
+                chdir $repo_name or croak $!;
 
                 $log->_7("chdir to: ".getcwd());
 
-                $log->_7("repo '".$git->name($repo)."' exists, pulling");
-                $log->_7("using Git: " . $git->git);
+                $log->_7("repo $repo_name exists");
 
                 if (defined $self->{auto} && $self->{auto}){
                     $log->_6("in auto mode");
 
+                    my $status = $git->status(repo => $git->link);
+                    my $local_sum = $git->revision(repo => $git->link);
+                    my $remote_sum = $git->revision(
+                        remote => 1,
+                        repo => $git->link
+                    );
+
+                    $log->_7(
+                        "\nGit check:" .
+                        "\n\tstatus: $status" .
+                        "\n\tlocal: $local_sum" .
+                        "\n\tremote: $remote_sum"
+                    );
+
                     if (! defined $self->{csum}){
                         $log->_6("in auto mode, checking commit checksum reqs");
 
-                        my $status = $git->status(repo => $git->link);
-                        my $local_sum = $git->revision(repo => $git->link);
-                        my $remote_sum = $git->revision(
-                            remote => 1,
-                            repo => $git->link
-                        );
-
-                        $log->_7(
-                            "\nGit check:" .
-                            "\n\tstatus: $status" .
-                            "\n\tlocal: $local_sum" .
-                            "\n\tremote: $remote_sum"
-                        );
-
                         if (! $status) {
                             $log->_6(
-                                "local repo is ahead in commits than remote... ".
-                                "Nothing to do"
+                                "local repo is ahead in commits than remote...".
+                                " Nothing to do"
                             );
                             $self->{log} = '';
                             shutdown($dispatch, 1);
@@ -326,7 +343,8 @@ sub listen {
 
                         if ($local_sum eq $remote_sum) {
                             $log->_6(
-                                "local and remote commit sums match. Nothing to do"
+                                "local and remote commit sums match. Nothing " .
+                                "to do"
                             );
                             $self->{log} = '';
                             shutdown($dispatch, 1);
@@ -335,8 +353,7 @@ sub listen {
                     }
                 }
 
-                $log->_7("repo '".$git->name($repo)."' exists, pulling");
-                $log->_7("using Git: " . $git->git);
+                $log->_7("pulling $repo_name");
 
                 my $pull_output = $git->pull;
                 $log->_7($pull_output);
@@ -363,10 +380,10 @@ sub listen {
                 $opt_str .= "$_ => $opts{$_}\n" if defined $opts{$_};
             }
             if ($opt_str){
-                $log->_5("commencing test run with args: $opt_str");
+                $log->_5("COMMENCING TEST RUN; args: $opt_str");
             }
             else {
-                $log->_5("commencing default brewbuild run with no args");
+                $log->_5("COMMENCING TEST RUN; no args (default)");
             }
 
             my $bb = Test::BrewBuild->new(%opts);
@@ -401,7 +418,13 @@ sub listen {
                 chdir 'bblog';
                 $log->_7("chdir to: ".getcwd());
                 my @entries = glob '*';
-                $log->_5("log files: " . join ', ', @entries);
+
+                if (@entries){
+                    $log->_5("log files: " . join ', ', @entries);
+                }
+                else {
+                    $log->_7("no log files generated, nothing to process");
+                }
                 for (@entries){
                     $log->_7("processing log file: " .getcwd() ."/$_");
                     next if ! -f || ! /\.bblog/;
@@ -463,12 +486,13 @@ sub _config {
     }
 }
 sub _pid_file {
-    # fetch the PID file location
+    # fetch the PID file location, and set the file
     my $self = shift;
     return $self->{pid_file} if defined $self->{pid_file};
     $self->{pid_file} = Test::BrewBuild->workdir . '/brewbuild.pid';
 }
 sub _unsafe_args {
+    # non-allowed chars in bbdispach's "-c" command line string for brewbuild
     return ['*', '#', '!', '?', '^', '$', '|', '\\'];
 }
 
